@@ -183,40 +183,30 @@ class Parser:
         token = self.lexer.current()
         if token.type == TokenType.KEYWORD and token.value == "FOREIGN":
             return self.match_foreign_key_constraint()
-        elif token.type == TokenType.IDENTIFIER:
+        elif token.type == TokenType.IDENTIFIER or token.type == TokenType.KEYWORD:
             return self.match_column()
         else:
             raise SQLiteParserError("expected start of column or constraint")
 
     @debuggable
     def match_column(self) -> ast.Column:
-        name_token = self.lexer.check([TokenType.IDENTIFIER])
-        type_token = self.lexer.advance()
-        if type_token.type != TokenType.IDENTIFIER:
-            return ast.Column(name=name_token.value, definition=None)
-
-        token = self.lexer.advance()
-        if token.type == TokenType.LEFT_PARENTHESIS:
-            args = []
-            while True:
-                token = self.lexer.advance()
-                if token.type == TokenType.RIGHT_PARENTHESIS:
-                    break
-                elif token.type == TokenType.INTEGER:
-                    args.append(int(token.value))
-                    token = self.lexer.advance()
-                    if token.type == TokenType.COMMA:
-                        continue
-                    elif token.type == TokenType.RIGHT_PARENTHESIS:
-                        break
-                    else:
-                        raise SQLiteParserError("expected comma or right parenthesis")
-
-            token = self.lexer.advance()
-            column_type = ast.ColumnType(name=type_token.value, args=args)
+        # SQLite allows some but not all SQL keywords to serve as column names. We are
+        # more permissive here. See #5 for details.
+        name_token = self.lexer.check([TokenType.IDENTIFIER, TokenType.KEYWORD])
+        if name_token.type == TokenType.KEYWORD:
+            # Use ``original_value`` because it preserves the original case of the
+            # identifier instead of putting it in all caps.
+            name = name_token.original_value
         else:
-            column_type = type_token.value
+            name = name_token.value
 
+        assert name is not None
+
+        column_type = self.match_column_type()
+        if column_type is None:
+            return ast.Column(name=name, definition=None)
+
+        token = self.lexer.current()
         constraints = []
         default = None
         while True:
@@ -237,13 +227,20 @@ class Parser:
                     constraints.append(self.match_generated_column_constraint())
                 elif token.value == "DEFAULT":
                     default = self.match_default_clause()
+                elif token.value == "NULL":
+                    # Django's ORM will produce columns with a NULL constraint, and
+                    # SQLite accepts it although it is not documented and appears to
+                    # have no effect.
+                    self.lexer.advance()
+                else:
+                    raise SQLiteParserError(f"unexpected keyword: {token.value}")
             else:
                 break
 
             token = self.lexer.current()
 
         return ast.Column(
-            name=name_token.value,
+            name=name,
             definition=ast.ColumnDefinition(
                 type=column_type,
                 default=default,
@@ -251,6 +248,39 @@ class Parser:
             ),
         )
 
+    @debuggable
+    def match_column_type(self) -> Optional[Union[str, ast.ColumnType]]:
+        type_token = self.lexer.advance()
+        if type_token.type != TokenType.IDENTIFIER:
+            return None
+
+        token = self.lexer.advance()
+        if token.type == TokenType.LEFT_PARENTHESIS:
+            args = []
+            while True:
+                token = self.lexer.advance()
+                if token.type == TokenType.RIGHT_PARENTHESIS:
+                    break
+                elif token.type == TokenType.INTEGER:
+                    args.append(int(token.value))
+                    token = self.lexer.advance()
+                    if token.type == TokenType.COMMA:
+                        continue
+                    elif token.type == TokenType.RIGHT_PARENTHESIS:
+                        break
+                    else:
+                        raise SQLiteParserError("expected comma or right parenthesis")
+
+            token = self.lexer.advance()
+            return ast.ColumnType(name=type_token.value, args=args)
+        else:
+            # SQL allows for multi-word column types, e.g. `smallint unsigned`.
+            name_parts = [type_token.value]
+            while token.type == TokenType.IDENTIFIER:
+                name_parts.append(token.value)
+                token = self.lexer.advance()
+            return " ".join(name_parts)
+
     @debuggable
     def match_foreign_key_constraint(self) -> ast.ForeignKeyConstraint:
         self.lexer.check(["FOREIGN"])
